# openapi_client

OpenapiClient - the Ruby gem for the ShipEngine API

ShipEngine's easy-to-use REST API lets you manage all of your shipping needs without worrying about the complexities of different carrier APIs and protocols. We handle all the heavy lifting so you can focus on providing a first-class shipping experience for your customers at the best possible prices.

Each of ShipEngine's features can be used by itself or in conjunction with each other to build powerful shipping functionality into your application or service.

## Getting Started
If you're new to REST APIs then be sure to read our [introduction to REST](https://www.shipengine.com/docs/rest/) to understand the basics. Learn how to [authenticate yourself to ShipEngine](https://www.shipengine.com/docs/auth/), and then use our [sandbox environment](https://www.shipengine.com/docs/sandbox/) to kick the tires and get familiar with our API. If you run into any problems, then be sure to check the [error handling guide](https://www.shipengine.com/docs/errors/) for tips.

Here are some step-by-step **tutorials** to get you started:

  - [Learn how to create your first shipping label](https://www.shipengine.com/docs/labels/create-a-label/)
  - [Calculate shipping costs and compare rates across carriers](https://www.shipengine.com/docs/rates/)
  - [Track packages on-demand or in real time](https://www.shipengine.com/docs/tracking/)
  - [Validate mailing addresses anywhere on Earth](https://www.shipengine.com/docs/addresses/validation/)


## Shipping Labels for Every Major Carrier
ShipEngine makes it easy to [create shipping labels for any carrier](https://www.shipengine.com/docs/labels/create-a-label/) and [download them](https://www.shipengine.com/docs/labels/downloading/) in a [variety of file formats](https://www.shipengine.com/docs/labels/formats/). You can even customize labels with your own [messages](https://www.shipengine.com/docs/labels/messages/) and [images](https://www.shipengine.com/docs/labels/branding/).


## Real-Time Package Tracking
With ShipEngine you can [get the current status of a package](https://www.shipengine.com/docs/tracking/) or [subscribe to real-time tracking updates](https://www.shipengine.com/docs/tracking/webhooks/) via webhooks. You can also create [custimized tracking pages](https://www.shipengine.com/docs/tracking/branded-tracking-page/) with your own branding so your customers will always know where their package is.


## Compare Shipping Costs Across Carriers
Make sure you ship as cost-effectively as possible by [comparing rates across carriers](https://www.shipengine.com/docs/rates/get-shipment-rates/) using the ShipEngine Rates API. Or if you don't know the full shipment details yet, then you can [get rate estimates](https://www.shipengine.com/docs/rates/estimate/) with limited address info.


## Worldwide Address Validation
ShipEngine supports [address validation](https://www.shipengine.com/docs/addresses/validation/) for virtually [every country on Earth](https://www.shipengine.com/docs/addresses/validation/countries/), including the United States, Canada, Great Britain, Australia, Germany, France, Norway, Spain, Sweden, Israel, Italy, and over 160 others.


This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.1.202006302006
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://www.shipengine.com/contact/](https://www.shipengine.com/contact/)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build openapi_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./openapi_client-1.0.0.gem
```

(for development, run `gem install --dev ./openapi_client-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'openapi_client', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'openapi_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'openapi_client'

# Setup authorization
OpenapiClient.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['API-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['API-Key'] = 'Bearer'
end

api_instance = OpenapiClient::AddressesApi.new
parse_address_request_body = {"text":"Margie McMiller at 3800 North Lamar suite 200 in austin, tx.  The zip code there is 78652."} # ParseAddressRequestBody | The only required field is `text`, which is the text to be parsed. You can optionally also provide an `address` containing already-known values. For example, you may already know the recipient's name, city, and country, and only want to parse the street address into separate lines. 

begin
  #Parse an address
  result = api_instance.parse_address(parse_address_request_body)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling AddressesApi->parse_address: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.shipengine.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OpenapiClient::AddressesApi* | [**parse_address**](docs/AddressesApi.md#parse_address) | **PUT** /v1/addresses/recognize | Parse an address
*OpenapiClient::AddressesApi* | [**validate_address**](docs/AddressesApi.md#validate_address) | **POST** /v1/addresses/validate | Validate An Address
*OpenapiClient::BatchesApi* | [**add_to_batch**](docs/BatchesApi.md#add_to_batch) | **POST** /v1/batches/{batch_id}/add | Add to a Batch
*OpenapiClient::BatchesApi* | [**create_batch**](docs/BatchesApi.md#create_batch) | **POST** /v1/batches | Create A Batch
*OpenapiClient::BatchesApi* | [**delete_batch**](docs/BatchesApi.md#delete_batch) | **DELETE** /v1/batches/{batch_id} | Delete Batch By Id
*OpenapiClient::BatchesApi* | [**get_batch_by_external_id**](docs/BatchesApi.md#get_batch_by_external_id) | **GET** /v1/batches/external_batch_id/{external_batch_id} | Get Batch By External ID
*OpenapiClient::BatchesApi* | [**get_batch_by_id**](docs/BatchesApi.md#get_batch_by_id) | **GET** /v1/batches/{batch_id} | Get Batch By ID
*OpenapiClient::BatchesApi* | [**list_batch_errors**](docs/BatchesApi.md#list_batch_errors) | **GET** /v1/batches/{batch_id}/errors | Get Batch Errors
*OpenapiClient::BatchesApi* | [**list_batches**](docs/BatchesApi.md#list_batches) | **GET** /v1/batches | List Batches
*OpenapiClient::BatchesApi* | [**process_batch**](docs/BatchesApi.md#process_batch) | **POST** /v1/batches/{batch_id}/process/labels | Process Batch ID Labels
*OpenapiClient::BatchesApi* | [**remove_from_batch**](docs/BatchesApi.md#remove_from_batch) | **POST** /v1/batches/{batch_id}/remove | Remove From Batch
*OpenapiClient::BatchesApi* | [**update_batch**](docs/BatchesApi.md#update_batch) | **PUT** /v1/batches/{batch_id} | Update Batch By Id
*OpenapiClient::CarrierAccountsApi* | [**connect_carrier**](docs/CarrierAccountsApi.md#connect_carrier) | **POST** /v1/connections/carriers/{carrier_name} | Connect a carrier account
*OpenapiClient::CarrierAccountsApi* | [**disconnect_carrier**](docs/CarrierAccountsApi.md#disconnect_carrier) | **DELETE** /v1/connections/carriers/{carrier_name}/{carrier_id} | Disconnect a carrier
*OpenapiClient::CarrierAccountsApi* | [**get_carrier_settings**](docs/CarrierAccountsApi.md#get_carrier_settings) | **GET** /v1/connections/carriers/{carrier_name}/{carrier_id}/settings | Get carrier settings
*OpenapiClient::CarrierAccountsApi* | [**update_carrier_settings**](docs/CarrierAccountsApi.md#update_carrier_settings) | **PUT** /v1/connections/carriers/{carrier_name}/{carrier_id}/settings | Update carrier settings
*OpenapiClient::CarriersApi* | [**add_funds_to_carrier**](docs/CarriersApi.md#add_funds_to_carrier) | **PUT** /v1/carriers/{carrier_id}/add_funds | Add Funds To Carrier
*OpenapiClient::CarriersApi* | [**get_carrier_by_id**](docs/CarriersApi.md#get_carrier_by_id) | **GET** /v1/carriers/{carrier_id} | Get Carrier By ID
*OpenapiClient::CarriersApi* | [**get_carrier_options**](docs/CarriersApi.md#get_carrier_options) | **GET** /v1/carriers/{carrier_id}/options | Get Carrier Options
*OpenapiClient::CarriersApi* | [**list_carrier_package_types**](docs/CarriersApi.md#list_carrier_package_types) | **GET** /v1/carriers/{carrier_id}/packages | List Carrier Package Types
*OpenapiClient::CarriersApi* | [**list_carrier_services**](docs/CarriersApi.md#list_carrier_services) | **GET** /v1/carriers/{carrier_id}/services | List Carrier Services
*OpenapiClient::CarriersApi* | [**list_carriers**](docs/CarriersApi.md#list_carriers) | **GET** /v1/carriers | List Carriers
*OpenapiClient::DownloadsApi* | [**download_file**](docs/DownloadsApi.md#download_file) | **GET** /v1/downloads/{dir}/{subdir}/{filename} | Download File
*OpenapiClient::InsuranceApi* | [**add_funds_to_insurance**](docs/InsuranceApi.md#add_funds_to_insurance) | **PATCH** /v1/insurance/shipsurance/add_funds | Add Funds To Insurance
*OpenapiClient::InsuranceApi* | [**connect_insurer**](docs/InsuranceApi.md#connect_insurer) | **POST** /v1/connections/insurance/shipsurance | Connect a Shipsurance Account
*OpenapiClient::InsuranceApi* | [**disconnect_insurer**](docs/InsuranceApi.md#disconnect_insurer) | **DELETE** /v1/connections/insurance/shipsurance | Disconnect a Shipsurance Account
*OpenapiClient::InsuranceApi* | [**get_insurance_balance**](docs/InsuranceApi.md#get_insurance_balance) | **GET** /v1/insurance/shipsurance/balance | Get Insurance Funds Balance
*OpenapiClient::LabelsApi* | [**create_label**](docs/LabelsApi.md#create_label) | **POST** /v1/labels | Purchase Label
*OpenapiClient::LabelsApi* | [**create_label_from_rate**](docs/LabelsApi.md#create_label_from_rate) | **POST** /v1/labels/rates/{rate_id} | Purchase Label with Rate ID
*OpenapiClient::LabelsApi* | [**create_label_from_shipment**](docs/LabelsApi.md#create_label_from_shipment) | **POST** /v1/labels/shipment/{shipment_id} | Purchase Label with Shipment ID
*OpenapiClient::LabelsApi* | [**create_return_label**](docs/LabelsApi.md#create_return_label) | **POST** /v1/labels/{label_id}/return | Create a return label
*OpenapiClient::LabelsApi* | [**get_label_by_external_shipment_id**](docs/LabelsApi.md#get_label_by_external_shipment_id) | **GET** /v1/labels/external_shipment_id/{external_shipment_id} | Get Label By External Shipment ID
*OpenapiClient::LabelsApi* | [**get_label_by_id**](docs/LabelsApi.md#get_label_by_id) | **GET** /v1/labels/{label_id} | Get Label By ID
*OpenapiClient::LabelsApi* | [**get_tracking_log_from_label**](docs/LabelsApi.md#get_tracking_log_from_label) | **GET** /v1/labels/{label_id}/track | Get Label Tracking Information
*OpenapiClient::LabelsApi* | [**list_labels**](docs/LabelsApi.md#list_labels) | **GET** /v1/labels | List labels
*OpenapiClient::LabelsApi* | [**void_label**](docs/LabelsApi.md#void_label) | **PUT** /v1/labels/{label_id}/void | Void a Label By ID
*OpenapiClient::ManifestsApi* | [**create_manifest**](docs/ManifestsApi.md#create_manifest) | **POST** /v1/manifests | Create Manifest
*OpenapiClient::ManifestsApi* | [**get_manifest_by_id**](docs/ManifestsApi.md#get_manifest_by_id) | **GET** /v1/manifests/{manifest_id} | Get Manifest By Id
*OpenapiClient::ManifestsApi* | [**list_manifests**](docs/ManifestsApi.md#list_manifests) | **GET** /v1/manifests | List Manifests
*OpenapiClient::PackageTypesApi* | [**create_package_type**](docs/PackageTypesApi.md#create_package_type) | **POST** /v1/packages | Create Custom Package Type
*OpenapiClient::PackageTypesApi* | [**delete_package_type**](docs/PackageTypesApi.md#delete_package_type) | **DELETE** /v1/packages/{package_id} | Delete A Custom Package By ID
*OpenapiClient::PackageTypesApi* | [**get_package_type_by_id**](docs/PackageTypesApi.md#get_package_type_by_id) | **GET** /v1/packages/{package_id} | Get Custom Package Type By ID
*OpenapiClient::PackageTypesApi* | [**list_package_types**](docs/PackageTypesApi.md#list_package_types) | **GET** /v1/packages | List Custom Package Types
*OpenapiClient::PackageTypesApi* | [**update_package_type**](docs/PackageTypesApi.md#update_package_type) | **PUT** /v1/packages/{package_id} | Update Custom Package Type By ID
*OpenapiClient::RatesApi* | [**calculate_rates**](docs/RatesApi.md#calculate_rates) | **POST** /v1/rates | Get Shipping Rates
*OpenapiClient::RatesApi* | [**compare_bulk_rates**](docs/RatesApi.md#compare_bulk_rates) | **POST** /v1/rates/bulk | Get Bulk Rates
*OpenapiClient::RatesApi* | [**estimate_rates**](docs/RatesApi.md#estimate_rates) | **POST** /v1/rates/estimate | Estimate Rates
*OpenapiClient::RatesApi* | [**get_rate_by_id**](docs/RatesApi.md#get_rate_by_id) | **GET** /v1/rates/{rate_id} | Get Rate By ID
*OpenapiClient::ShipmentsApi* | [**cancel_shipments**](docs/ShipmentsApi.md#cancel_shipments) | **PUT** /v1/shipments/{shipment_id}/cancel | Cancel a Shipment
*OpenapiClient::ShipmentsApi* | [**create_shipments**](docs/ShipmentsApi.md#create_shipments) | **POST** /v1/shipments | Create Shipments
*OpenapiClient::ShipmentsApi* | [**get_shipment_by_external_id**](docs/ShipmentsApi.md#get_shipment_by_external_id) | **GET** /v1/shipments/external_shipment_id/{external_shipment_id} | Get Shipment By External ID
*OpenapiClient::ShipmentsApi* | [**get_shipment_by_id**](docs/ShipmentsApi.md#get_shipment_by_id) | **GET** /v1/shipments/{shipment_id} | Get Shipment By ID
*OpenapiClient::ShipmentsApi* | [**list_shipment_errors**](docs/ShipmentsApi.md#list_shipment_errors) | **GET** /v1/shipments/{shipment_id}/errors | Get Shipment Errors
*OpenapiClient::ShipmentsApi* | [**list_shipment_rates**](docs/ShipmentsApi.md#list_shipment_rates) | **GET** /v1/shipments/{shipment_id}/rates | Get Shipment Rates
*OpenapiClient::ShipmentsApi* | [**list_shipments**](docs/ShipmentsApi.md#list_shipments) | **GET** /v1/shipments | List Shipments
*OpenapiClient::ShipmentsApi* | [**parse_shipment**](docs/ShipmentsApi.md#parse_shipment) | **PUT** /v1/shipments/recognize | Parse shipping info
*OpenapiClient::ShipmentsApi* | [**tag_shipment**](docs/ShipmentsApi.md#tag_shipment) | **POST** /v1/shipments/{shipment_id}/tags/{tag_name} | Add Tag to Shipment
*OpenapiClient::ShipmentsApi* | [**untag_shipment**](docs/ShipmentsApi.md#untag_shipment) | **DELETE** /v1/shipments/{shipment_id}/tags/{tag_name} | Remove Tag from Shipment
*OpenapiClient::ShipmentsApi* | [**update_shipment**](docs/ShipmentsApi.md#update_shipment) | **PUT** /v1/shipments/{shipment_id} | Update Shipment By ID
*OpenapiClient::TagsApi* | [**create_tag**](docs/TagsApi.md#create_tag) | **POST** /v1/tags/{tag_name} | Create a New Tag
*OpenapiClient::TagsApi* | [**delete_tag**](docs/TagsApi.md#delete_tag) | **DELETE** /v1/tags/{tag_name} | Delete Tag
*OpenapiClient::TagsApi* | [**list_tags**](docs/TagsApi.md#list_tags) | **GET** /v1/tags | Get Tags
*OpenapiClient::TagsApi* | [**rename_tag**](docs/TagsApi.md#rename_tag) | **PUT** /v1/tags/{tag_name}/{new_tag_name} | Update Tag Name
*OpenapiClient::TrackingApi* | [**get_tracking_log**](docs/TrackingApi.md#get_tracking_log) | **GET** /v1/tracking | Get Tracking Information
*OpenapiClient::TrackingApi* | [**start_tracking**](docs/TrackingApi.md#start_tracking) | **POST** /v1/tracking/start | Start Tracking a Package
*OpenapiClient::TrackingApi* | [**stop_tracking**](docs/TrackingApi.md#stop_tracking) | **POST** /v1/tracking/stop | Stop Tracking a Package
*OpenapiClient::WarehousesApi* | [**create_warehouse**](docs/WarehousesApi.md#create_warehouse) | **POST** /v1/warehouses | Create Warehouse
*OpenapiClient::WarehousesApi* | [**delete_warehouse**](docs/WarehousesApi.md#delete_warehouse) | **DELETE** /v1/warehouses/{warehouse_id} | Delete Warehouse By ID
*OpenapiClient::WarehousesApi* | [**get_warehouse_by_id**](docs/WarehousesApi.md#get_warehouse_by_id) | **GET** /v1/warehouses/{warehouse_id} | Get Warehouse By Id
*OpenapiClient::WarehousesApi* | [**list_warehouses**](docs/WarehousesApi.md#list_warehouses) | **GET** /v1/warehouses | List Warehouses
*OpenapiClient::WarehousesApi* | [**update_warehouse**](docs/WarehousesApi.md#update_warehouse) | **PUT** /v1/warehouses/{warehouse_id} | Update WareHouse By Id
*OpenapiClient::WebhooksApi* | [**create_webhook**](docs/WebhooksApi.md#create_webhook) | **POST** /v1/environment/webhooks | Create a Webhook
*OpenapiClient::WebhooksApi* | [**delete_webhook**](docs/WebhooksApi.md#delete_webhook) | **DELETE** /v1/environment/webhooks/{webhook_id} | Delete Webhook By ID
*OpenapiClient::WebhooksApi* | [**get_webhook_by_id**](docs/WebhooksApi.md#get_webhook_by_id) | **GET** /v1/environment/webhooks/{webhook_id} | Get Webhook By ID
*OpenapiClient::WebhooksApi* | [**list_webhooks**](docs/WebhooksApi.md#list_webhooks) | **GET** /v1/environment/webhooks | List Webhooks
*OpenapiClient::WebhooksApi* | [**update_webhook**](docs/WebhooksApi.md#update_webhook) | **PUT** /v1/environment/webhooks/{webhook_id} | Update a Webhook


## Documentation for Models

 - [OpenapiClient::AddFundsToCarrierRequestBody](docs/AddFundsToCarrierRequestBody.md)
 - [OpenapiClient::AddFundsToCarrierResponseBody](docs/AddFundsToCarrierResponseBody.md)
 - [OpenapiClient::AddFundsToInsuranceRequestBody](docs/AddFundsToInsuranceRequestBody.md)
 - [OpenapiClient::AddFundsToInsuranceResponseBody](docs/AddFundsToInsuranceResponseBody.md)
 - [OpenapiClient::AddToBatchRequestBody](docs/AddToBatchRequestBody.md)
 - [OpenapiClient::Address](docs/Address.md)
 - [OpenapiClient::AddressResidentialIndicator](docs/AddressResidentialIndicator.md)
 - [OpenapiClient::AddressToValidate](docs/AddressToValidate.md)
 - [OpenapiClient::AddressValidatingShipment](docs/AddressValidatingShipment.md)
 - [OpenapiClient::AddressValidationCode](docs/AddressValidationCode.md)
 - [OpenapiClient::AddressValidationDetailCode](docs/AddressValidationDetailCode.md)
 - [OpenapiClient::AddressValidationMessageType](docs/AddressValidationMessageType.md)
 - [OpenapiClient::AddressValidationResult](docs/AddressValidationResult.md)
 - [OpenapiClient::AddressValidationStatus](docs/AddressValidationStatus.md)
 - [OpenapiClient::AdvancedShipmentOptions](docs/AdvancedShipmentOptions.md)
 - [OpenapiClient::AncillaryServiceEndorsement](docs/AncillaryServiceEndorsement.md)
 - [OpenapiClient::Batch](docs/Batch.md)
 - [OpenapiClient::BatchResponseError](docs/BatchResponseError.md)
 - [OpenapiClient::BatchStatus](docs/BatchStatus.md)
 - [OpenapiClient::BatchesSortBy](docs/BatchesSortBy.md)
 - [OpenapiClient::BillToParty](docs/BillToParty.md)
 - [OpenapiClient::BulkRate](docs/BulkRate.md)
 - [OpenapiClient::CalculateRatesRequestBody](docs/CalculateRatesRequestBody.md)
 - [OpenapiClient::CalculateRatesResponseBody](docs/CalculateRatesResponseBody.md)
 - [OpenapiClient::Carrier](docs/Carrier.md)
 - [OpenapiClient::CarrierAdvancedOption](docs/CarrierAdvancedOption.md)
 - [OpenapiClient::CarrierName](docs/CarrierName.md)
 - [OpenapiClient::CarrierNameWithSettings](docs/CarrierNameWithSettings.md)
 - [OpenapiClient::CollectOnDelivery](docs/CollectOnDelivery.md)
 - [OpenapiClient::CollectOnDeliveryPaymentType](docs/CollectOnDeliveryPaymentType.md)
 - [OpenapiClient::CompareBulkRatesRequestBody](docs/CompareBulkRatesRequestBody.md)
 - [OpenapiClient::ConnectAccessWorldwideRequestBody](docs/ConnectAccessWorldwideRequestBody.md)
 - [OpenapiClient::ConnectAmazonBuyShippingRequestBody](docs/ConnectAmazonBuyShippingRequestBody.md)
 - [OpenapiClient::ConnectApcRequestBody](docs/ConnectApcRequestBody.md)
 - [OpenapiClient::ConnectAsendiaRequestBody](docs/ConnectAsendiaRequestBody.md)
 - [OpenapiClient::ConnectAustraliaPostRequestBody](docs/ConnectAustraliaPostRequestBody.md)
 - [OpenapiClient::ConnectCanadaPostRequestBody](docs/ConnectCanadaPostRequestBody.md)
 - [OpenapiClient::ConnectCarrierRequestBody](docs/ConnectCarrierRequestBody.md)
 - [OpenapiClient::ConnectCarrierResponseBody](docs/ConnectCarrierResponseBody.md)
 - [OpenapiClient::ConnectDhlEcommerceRequestBody](docs/ConnectDhlEcommerceRequestBody.md)
 - [OpenapiClient::ConnectDhlExpressAuRequestBody](docs/ConnectDhlExpressAuRequestBody.md)
 - [OpenapiClient::ConnectDhlExpressCaRequestBody](docs/ConnectDhlExpressCaRequestBody.md)
 - [OpenapiClient::ConnectDhlExpressRequestBody](docs/ConnectDhlExpressRequestBody.md)
 - [OpenapiClient::ConnectDhlExpressUkRequestBody](docs/ConnectDhlExpressUkRequestBody.md)
 - [OpenapiClient::ConnectDpdRequestBody](docs/ConnectDpdRequestBody.md)
 - [OpenapiClient::ConnectEndiciaRequestBody](docs/ConnectEndiciaRequestBody.md)
 - [OpenapiClient::ConnectFedexRequestBody](docs/ConnectFedexRequestBody.md)
 - [OpenapiClient::ConnectFedexUkRequestBody](docs/ConnectFedexUkRequestBody.md)
 - [OpenapiClient::ConnectFirstmileRequestBody](docs/ConnectFirstmileRequestBody.md)
 - [OpenapiClient::ConnectGlobegisticsRequestBody](docs/ConnectGlobegisticsRequestBody.md)
 - [OpenapiClient::ConnectImexRequestBody](docs/ConnectImexRequestBody.md)
 - [OpenapiClient::ConnectInsurerRequestBody](docs/ConnectInsurerRequestBody.md)
 - [OpenapiClient::ConnectNewgisticsRequestBody](docs/ConnectNewgisticsRequestBody.md)
 - [OpenapiClient::ConnectOntracRequestBody](docs/ConnectOntracRequestBody.md)
 - [OpenapiClient::ConnectPurolatorRequestBody](docs/ConnectPurolatorRequestBody.md)
 - [OpenapiClient::ConnectRoyalMailRequestBody](docs/ConnectRoyalMailRequestBody.md)
 - [OpenapiClient::ConnectRrDonnelleyRequestBody](docs/ConnectRrDonnelleyRequestBody.md)
 - [OpenapiClient::ConnectSekoRequestBody](docs/ConnectSekoRequestBody.md)
 - [OpenapiClient::ConnectSendleRequestBody](docs/ConnectSendleRequestBody.md)
 - [OpenapiClient::ConnectStampsRequestBody](docs/ConnectStampsRequestBody.md)
 - [OpenapiClient::ConnectUpsRequestBody](docs/ConnectUpsRequestBody.md)
 - [OpenapiClient::CreateAndValidateShipment](docs/CreateAndValidateShipment.md)
 - [OpenapiClient::CreateBatchRequestBody](docs/CreateBatchRequestBody.md)
 - [OpenapiClient::CreateBatchResponseBody](docs/CreateBatchResponseBody.md)
 - [OpenapiClient::CreateLabelFromRateRequestBody](docs/CreateLabelFromRateRequestBody.md)
 - [OpenapiClient::CreateLabelFromRateResponseBody](docs/CreateLabelFromRateResponseBody.md)
 - [OpenapiClient::CreateLabelFromShipmentRequestBody](docs/CreateLabelFromShipmentRequestBody.md)
 - [OpenapiClient::CreateLabelFromShipmentResponseBody](docs/CreateLabelFromShipmentResponseBody.md)
 - [OpenapiClient::CreateLabelRequestBody](docs/CreateLabelRequestBody.md)
 - [OpenapiClient::CreateLabelResponseBody](docs/CreateLabelResponseBody.md)
 - [OpenapiClient::CreateManifestByObjectRequestBody](docs/CreateManifestByObjectRequestBody.md)
 - [OpenapiClient::CreateManifestLabelIdsRequestBody](docs/CreateManifestLabelIdsRequestBody.md)
 - [OpenapiClient::CreateManifestRequestBody](docs/CreateManifestRequestBody.md)
 - [OpenapiClient::CreateManifestResponseBody](docs/CreateManifestResponseBody.md)
 - [OpenapiClient::CreatePackageTypeRequestBody](docs/CreatePackageTypeRequestBody.md)
 - [OpenapiClient::CreatePackageTypeResponseBody](docs/CreatePackageTypeResponseBody.md)
 - [OpenapiClient::CreateReturnLabelRequestBody](docs/CreateReturnLabelRequestBody.md)
 - [OpenapiClient::CreateReturnLabelResponseBody](docs/CreateReturnLabelResponseBody.md)
 - [OpenapiClient::CreateShipmentResponseBodyFields](docs/CreateShipmentResponseBodyFields.md)
 - [OpenapiClient::CreateShipmentsRequestBody](docs/CreateShipmentsRequestBody.md)
 - [OpenapiClient::CreateShipmentsResponseBody](docs/CreateShipmentsResponseBody.md)
 - [OpenapiClient::CreateTagResponseBody](docs/CreateTagResponseBody.md)
 - [OpenapiClient::CreateWarehouseRequestBody](docs/CreateWarehouseRequestBody.md)
 - [OpenapiClient::CreateWarehouseResponseBody](docs/CreateWarehouseResponseBody.md)
 - [OpenapiClient::CreateWebhookRequestBody](docs/CreateWebhookRequestBody.md)
 - [OpenapiClient::CreateWebhookResponseBody](docs/CreateWebhookResponseBody.md)
 - [OpenapiClient::Currency](docs/Currency.md)
 - [OpenapiClient::CustomsItem](docs/CustomsItem.md)
 - [OpenapiClient::DeliveryConfirmation](docs/DeliveryConfirmation.md)
 - [OpenapiClient::DeprecatedManifest](docs/DeprecatedManifest.md)
 - [OpenapiClient::DhlExpressAccountSettings](docs/DhlExpressAccountSettings.md)
 - [OpenapiClient::DhlExpressSettingsResponseBody](docs/DhlExpressSettingsResponseBody.md)
 - [OpenapiClient::DimensionUnit](docs/DimensionUnit.md)
 - [OpenapiClient::Dimensions](docs/Dimensions.md)
 - [OpenapiClient::Error](docs/Error.md)
 - [OpenapiClient::ErrorCode](docs/ErrorCode.md)
 - [OpenapiClient::ErrorResponseBody](docs/ErrorResponseBody.md)
 - [OpenapiClient::ErrorSource](docs/ErrorSource.md)
 - [OpenapiClient::ErrorType](docs/ErrorType.md)
 - [OpenapiClient::EstimateRatesRequestBody](docs/EstimateRatesRequestBody.md)
 - [OpenapiClient::FedexAccountSettings](docs/FedexAccountSettings.md)
 - [OpenapiClient::FedexAccountSettingsRequestBody](docs/FedexAccountSettingsRequestBody.md)
 - [OpenapiClient::FedexPickupType](docs/FedexPickupType.md)
 - [OpenapiClient::FedexSettingsResponseBody](docs/FedexSettingsResponseBody.md)
 - [OpenapiClient::GetBatchByExternalIdResponseBody](docs/GetBatchByExternalIdResponseBody.md)
 - [OpenapiClient::GetBatchByIdResponseBody](docs/GetBatchByIdResponseBody.md)
 - [OpenapiClient::GetCarrierByIdResponseBody](docs/GetCarrierByIdResponseBody.md)
 - [OpenapiClient::GetCarrierOptionsResponseBody](docs/GetCarrierOptionsResponseBody.md)
 - [OpenapiClient::GetCarrierSettingsResponseBody](docs/GetCarrierSettingsResponseBody.md)
 - [OpenapiClient::GetCarriersResponseBody](docs/GetCarriersResponseBody.md)
 - [OpenapiClient::GetInsuranceBalanceResponseBody](docs/GetInsuranceBalanceResponseBody.md)
 - [OpenapiClient::GetLabelByExternalShipmentIdResponseBody](docs/GetLabelByExternalShipmentIdResponseBody.md)
 - [OpenapiClient::GetLabelByIdResponseBody](docs/GetLabelByIdResponseBody.md)
 - [OpenapiClient::GetManifestByIdResponseBody](docs/GetManifestByIdResponseBody.md)
 - [OpenapiClient::GetPackageTypeByIdResponseBody](docs/GetPackageTypeByIdResponseBody.md)
 - [OpenapiClient::GetRateByIdResponseBody](docs/GetRateByIdResponseBody.md)
 - [OpenapiClient::GetShipmentByExternalIdResponseBody](docs/GetShipmentByExternalIdResponseBody.md)
 - [OpenapiClient::GetShipmentByIdResponseBody](docs/GetShipmentByIdResponseBody.md)
 - [OpenapiClient::GetTrackingLogFromLabelResponseBody](docs/GetTrackingLogFromLabelResponseBody.md)
 - [OpenapiClient::GetTrackingLogResponseBody](docs/GetTrackingLogResponseBody.md)
 - [OpenapiClient::GetWarehouseByIdResponseBody](docs/GetWarehouseByIdResponseBody.md)
 - [OpenapiClient::GetWebhookByIdResponseBody](docs/GetWebhookByIdResponseBody.md)
 - [OpenapiClient::InsuranceProvider](docs/InsuranceProvider.md)
 - [OpenapiClient::InternationalShipmentOptions](docs/InternationalShipmentOptions.md)
 - [OpenapiClient::Label](docs/Label.md)
 - [OpenapiClient::LabelChargeEvent](docs/LabelChargeEvent.md)
 - [OpenapiClient::LabelDownload](docs/LabelDownload.md)
 - [OpenapiClient::LabelDownloadType](docs/LabelDownloadType.md)
 - [OpenapiClient::LabelFormat](docs/LabelFormat.md)
 - [OpenapiClient::LabelLayout](docs/LabelLayout.md)
 - [OpenapiClient::LabelMessages](docs/LabelMessages.md)
 - [OpenapiClient::LabelStatus](docs/LabelStatus.md)
 - [OpenapiClient::Link](docs/Link.md)
 - [OpenapiClient::ListBatchErrorsResponseBody](docs/ListBatchErrorsResponseBody.md)
 - [OpenapiClient::ListBatchesResponseBody](docs/ListBatchesResponseBody.md)
 - [OpenapiClient::ListCarrierPackageTypesResponseBody](docs/ListCarrierPackageTypesResponseBody.md)
 - [OpenapiClient::ListCarrierServicesResponseBody](docs/ListCarrierServicesResponseBody.md)
 - [OpenapiClient::ListCarriersResponseBody](docs/ListCarriersResponseBody.md)
 - [OpenapiClient::ListLabelsResponseBody](docs/ListLabelsResponseBody.md)
 - [OpenapiClient::ListManifestsResponseBody](docs/ListManifestsResponseBody.md)
 - [OpenapiClient::ListPackageTypesResponseBody](docs/ListPackageTypesResponseBody.md)
 - [OpenapiClient::ListShipmentErrorsResponseBody](docs/ListShipmentErrorsResponseBody.md)
 - [OpenapiClient::ListShipmentRatesResponseBody](docs/ListShipmentRatesResponseBody.md)
 - [OpenapiClient::ListShipmentsResponseBody](docs/ListShipmentsResponseBody.md)
 - [OpenapiClient::ListTagsResponseBody](docs/ListTagsResponseBody.md)
 - [OpenapiClient::ListWarehousesResponseBody](docs/ListWarehousesResponseBody.md)
 - [OpenapiClient::Manifest](docs/Manifest.md)
 - [OpenapiClient::ManifestDownload](docs/ManifestDownload.md)
 - [OpenapiClient::Manifests](docs/Manifests.md)
 - [OpenapiClient::ModifyBatch](docs/ModifyBatch.md)
 - [OpenapiClient::MonetaryValue](docs/MonetaryValue.md)
 - [OpenapiClient::NonDelivery](docs/NonDelivery.md)
 - [OpenapiClient::OptionalLink](docs/OptionalLink.md)
 - [OpenapiClient::OrderSourceName](docs/OrderSourceName.md)
 - [OpenapiClient::Package](docs/Package.md)
 - [OpenapiClient::PackageContents](docs/PackageContents.md)
 - [OpenapiClient::PackageType](docs/PackageType.md)
 - [OpenapiClient::PagedListResponseBody](docs/PagedListResponseBody.md)
 - [OpenapiClient::PaginationLink](docs/PaginationLink.md)
 - [OpenapiClient::ParseAddressRequestBody](docs/ParseAddressRequestBody.md)
 - [OpenapiClient::ParseAddressResponseBody](docs/ParseAddressResponseBody.md)
 - [OpenapiClient::ParseShipmentRequestBody](docs/ParseShipmentRequestBody.md)
 - [OpenapiClient::ParseShipmentResponseBody](docs/ParseShipmentResponseBody.md)
 - [OpenapiClient::PartialAddress](docs/PartialAddress.md)
 - [OpenapiClient::PartialShipment](docs/PartialShipment.md)
 - [OpenapiClient::PaymentAmount](docs/PaymentAmount.md)
 - [OpenapiClient::ProcessBatchRequestBody](docs/ProcessBatchRequestBody.md)
 - [OpenapiClient::PurchaseLabelWithoutShipment](docs/PurchaseLabelWithoutShipment.md)
 - [OpenapiClient::Rate](docs/Rate.md)
 - [OpenapiClient::RateEstimateByCarrierId](docs/RateEstimateByCarrierId.md)
 - [OpenapiClient::RateEstimateByCarrierIds](docs/RateEstimateByCarrierIds.md)
 - [OpenapiClient::RateEstimateOptions](docs/RateEstimateOptions.md)
 - [OpenapiClient::RateRequestBody](docs/RateRequestBody.md)
 - [OpenapiClient::RateRequestByShipmentIds](docs/RateRequestByShipmentIds.md)
 - [OpenapiClient::RateRequestByShipments](docs/RateRequestByShipments.md)
 - [OpenapiClient::RateRequestOptions](docs/RateRequestOptions.md)
 - [OpenapiClient::RateRequestRateOptions](docs/RateRequestRateOptions.md)
 - [OpenapiClient::RateResponse](docs/RateResponse.md)
 - [OpenapiClient::RateResponseStatus](docs/RateResponseStatus.md)
 - [OpenapiClient::RateType](docs/RateType.md)
 - [OpenapiClient::RatesInformation](docs/RatesInformation.md)
 - [OpenapiClient::RecognizedEntity](docs/RecognizedEntity.md)
 - [OpenapiClient::RemoveFromBatchRequestBody](docs/RemoveFromBatchRequestBody.md)
 - [OpenapiClient::ResponseMessage](docs/ResponseMessage.md)
 - [OpenapiClient::Service](docs/Service.md)
 - [OpenapiClient::Shipment](docs/Shipment.md)
 - [OpenapiClient::ShipmentIdRequest](docs/ShipmentIdRequest.md)
 - [OpenapiClient::ShipmentItem](docs/ShipmentItem.md)
 - [OpenapiClient::ShipmentRequest](docs/ShipmentRequest.md)
 - [OpenapiClient::ShipmentResponseError](docs/ShipmentResponseError.md)
 - [OpenapiClient::ShipmentStatus](docs/ShipmentStatus.md)
 - [OpenapiClient::ShipmentsSortBy](docs/ShipmentsSortBy.md)
 - [OpenapiClient::SmartPostHub](docs/SmartPostHub.md)
 - [OpenapiClient::SortDir](docs/SortDir.md)
 - [OpenapiClient::Tag](docs/Tag.md)
 - [OpenapiClient::TagShipmentResponseBody](docs/TagShipmentResponseBody.md)
 - [OpenapiClient::TrackEvent](docs/TrackEvent.md)
 - [OpenapiClient::TrackingInformation](docs/TrackingInformation.md)
 - [OpenapiClient::TrackingStatus](docs/TrackingStatus.md)
 - [OpenapiClient::UpdateAmazonBuyShippingRequestBody](docs/UpdateAmazonBuyShippingRequestBody.md)
 - [OpenapiClient::UpdateCarrierSettingsRequestBody](docs/UpdateCarrierSettingsRequestBody.md)
 - [OpenapiClient::UpdateDhlExpressSettingsRequestBody](docs/UpdateDhlExpressSettingsRequestBody.md)
 - [OpenapiClient::UpdateFedexSettingsRequestBody](docs/UpdateFedexSettingsRequestBody.md)
 - [OpenapiClient::UpdateNewgisticsSettingsRequestBody](docs/UpdateNewgisticsSettingsRequestBody.md)
 - [OpenapiClient::UpdatePackageTypeRequestBody](docs/UpdatePackageTypeRequestBody.md)
 - [OpenapiClient::UpdateShipmentFields](docs/UpdateShipmentFields.md)
 - [OpenapiClient::UpdateShipmentRequestBody](docs/UpdateShipmentRequestBody.md)
 - [OpenapiClient::UpdateShipmentResponseBody](docs/UpdateShipmentResponseBody.md)
 - [OpenapiClient::UpdateUpsSettingsRequestBody](docs/UpdateUpsSettingsRequestBody.md)
 - [OpenapiClient::UpdateWarehouseRequestBody](docs/UpdateWarehouseRequestBody.md)
 - [OpenapiClient::UpdateWebhookRequestBody](docs/UpdateWebhookRequestBody.md)
 - [OpenapiClient::UpsAccountSettings](docs/UpsAccountSettings.md)
 - [OpenapiClient::UpsInvoice](docs/UpsInvoice.md)
 - [OpenapiClient::UpsPickupType](docs/UpsPickupType.md)
 - [OpenapiClient::UpsSettingsResponseBody](docs/UpsSettingsResponseBody.md)
 - [OpenapiClient::ValidateAddress](docs/ValidateAddress.md)
 - [OpenapiClient::ValidateShipmentFields](docs/ValidateShipmentFields.md)
 - [OpenapiClient::ValidationStatus](docs/ValidationStatus.md)
 - [OpenapiClient::VoidLabelResponseBody](docs/VoidLabelResponseBody.md)
 - [OpenapiClient::Warehouse](docs/Warehouse.md)
 - [OpenapiClient::Webhook](docs/Webhook.md)
 - [OpenapiClient::WebhookEvent](docs/WebhookEvent.md)
 - [OpenapiClient::Weight](docs/Weight.md)
 - [OpenapiClient::WeightUnit](docs/WeightUnit.md)


## Documentation for Authorization


### api_key


- **Type**: API key
- **API key parameter name**: API-Key
- **Location**: HTTP header

